import * as i0 from '@angular/core';
import { inject, ElementRef, Directive, Input, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

class AutoFocusDirective {
    static attributeKey = Symbol('AutoFocusDirectiveAttributeKey');
    static callbackCache = new Map();
    static fireOnceSettings = new Map();
    static observer = new IntersectionObserver((entries) => entries
        .filter((entry) => entry.isIntersecting)
        .map((entry) => {
        const { target } = entry;
        if (!(target instanceof HTMLElement))
            throw TypeError('Must observe HTML elements');
        return target;
    })
        .forEach((el) => {
        const uniqueKey = el[AutoFocusDirective.attributeKey];
        if (!uniqueKey)
            throw TypeError('HTML element has no auto focus attribute key.');
        const callback = AutoFocusDirective.callbackCache.get(uniqueKey);
        if (!callback)
            throw TypeError('Auto focus callback not cached.');
        callback();
        /** Only auto focus once! */
        const isFireOnce = Boolean(AutoFocusDirective.fireOnceSettings.get(uniqueKey));
        if (isFireOnce) {
            AutoFocusDirective.observer.unobserve(el);
        }
    }));
    customCallback;
    once = true;
    uniqueKey = Symbol('InstanceStaticCacheKey');
    el = inject(ElementRef);
    get nativeElement() {
        if (!(this.el.nativeElement instanceof HTMLElement))
            throw TypeError('Auto focus must be used with an HTML element.');
        return this.el.nativeElement;
    }
    ngAfterViewInit() {
        this.nativeElement[AutoFocusDirective.attributeKey] = this.uniqueKey;
        AutoFocusDirective.callbackCache.set(this.uniqueKey, this.customCallback ?? (() => this.nativeElement.focus()));
        AutoFocusDirective.fireOnceSettings.set(this.uniqueKey, this.once);
        AutoFocusDirective.observer.observe(this.nativeElement);
    }
    ngOnDestroy() {
        AutoFocusDirective.observer.unobserve(this.nativeElement);
        AutoFocusDirective.callbackCache.delete(this.uniqueKey);
        AutoFocusDirective.fireOnceSettings.delete(this.uniqueKey);
    }
    static ngTemplateContextGuard(_directive, _context) {
        return true;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: AutoFocusDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.8", type: AutoFocusDirective, selector: "[ngxAutofocus]", inputs: { customCallback: "customCallback", once: "once" }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: AutoFocusDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngxAutofocus]',
                }]
        }], propDecorators: { customCallback: [{
                type: Input
            }], once: [{
                type: Input
            }] } });

class NgxVisibleAutofocusModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: NgxVisibleAutofocusModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.8", ngImport: i0, type: NgxVisibleAutofocusModule, declarations: [AutoFocusDirective], imports: [CommonModule], exports: [AutoFocusDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: NgxVisibleAutofocusModule, imports: [CommonModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: NgxVisibleAutofocusModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AutoFocusDirective],
                    imports: [CommonModule],
                    exports: [AutoFocusDirective],
                }]
        }] });

/*
 * Public API Surface of ngx-visible-autofocus
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AutoFocusDirective, NgxVisibleAutofocusModule };
//# sourceMappingURL=ngx-visible-autofocus.mjs.map
